# 最新の物件情報一覧の取得

## 本プログラムの説明
指定したフォルダ内の物件から最新の結果データを判別し、各物件の情報をExcel形式の一覧として出力するものです。
物件の計算状態に応じて、出力される情報は以下のとおりです。
※　対象物件が指定した『SS7』のバージョンより古い場合、コピーして変換して開き、準備計算まで行います。
### 出力される項目
| 計算状態 | 出力される項目 |
| :---- |----- |
| － | 物件プレビュー、物件フォルダ、フォルダパス、『SS7』バージョン、最新結果、更新日時 |
| 準備計算 | 工事名称、略称、日付、担当者名、スパン数（X/Y）、階数、地下階数、PH階数<br>構造種別の有無、計算ルートの構造種別、計算ルート（X/Y）<br>保有水平耐力計算の有無（X正/Y正/X負/Y負）、基礎形式、延べ床面積 |
| 断面算定 | 建物高さ、スパン長さ、塔状比（X/Y） |
| 必要保有水平耐力 | Qu/Qun（X/Y） |

![](./docs/image/image_1.png)
<div style="page-break-before:always"></div>

## 本プログラムの実行方法
1. **パラメータ設定**
    `main.py`ファイルを編集して必要なパラメータを設定してください。
    | 変数名 | 説明 | デフォルト |
    | :---- |----- | :------: |
    | base_path | 対象とするフォルダパス | "C:\UsrData\Ss7Data" |
    | excel_file_name | 保存するExcelファイル名 |  "folder_information.xlsx"   |
    | ss7_version | 『SS7』のバージョン（例："1.1.1.20"）<br>※Noneは最新バージョン |  None  |
2. **プログラム実行**
   コマンドラインで以下の手順に従ってプログラムを実行します。
   例) C:に「example」というフォルダ名で配置する場合
    ```cmd
    cd C:\example\src
    python main.py
    ```
3. **結果の確認**:
   結果は`output`フォルダ内に`保存するExcelファイル名`でExcelファイルとして保存されます。

## 注意事項
* 本プログラムは『SS7』Ver1.1.1.20で動作確認を行っています。
※バージョンを変更するには、`ss7_version`パラメータを変更してください。
* プログラムの使用にあたっては、適切なデータファイルの準備やパラメータの設定を行ってください。
* フォルダ内の最新の結果データが取得されます。
* 対象物件が指定した『SS7』のバージョンより新しい場合、計算は行われません。

## 『Op.Python実行』の設定手順
Ss7Pythonライブラリを使用するための設定手順です。
1. 『SS7』を起動し，[ツール－環境設定－Op.Python実行]画面を表示します。
2. “利用可能なPython言語のバージョン”を選択し，[デスクトップへコピー]ボタンをクリックします。
3. デスクトップにある「Python」フォルダごと，「src」フォルダにコピーします。
<div style="page-break-before:always"></div>

## 必要な外部ライブラリ
以下の外部ライブラリをPython実行環境にインストールしてください。
- pandas　　2.2.2
- openpyxl　3.1.5
- pillow　　10.4.0

```cmd
pip install pandas==2.2.2
pip install openpyxl==3.1.5
pip install pillow==10.4.0
```

外部ライブラリのライセンスは「LICENSES/ライセンスについて.txt」を確認してください。

## 著作者
Copyright(C) 2024 UNION SYSTEM Inc.


## ライセンス
本プログラムは MIT License に基づいています。「LICENSE」を確認してください。
